xlwt documentation
==================

xlwt is a library for writing data and formatting information to older Excel
files (ie: .xls)

Documentation is sparse, please see the API reference or code for help:

.. toctree::
   :maxdepth: 1

   api.rst

Perhaps more useful is to consult the `tutorial`__ and the examples in the
`examples` folder of the distribution.

__ https://github.com/python-excel/tutorial

For details of how to install the package or get involved in its
development, please see the sections below:

.. toctree::
   :maxdepth: 1

   installation.rst
   development.rst
   changes.rst
   licenses.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
